@@ -4,7 +4,7 @@ use v5.10;
 use Moo::Role;
 use MooX::Types::MooseLike::Base qw(:all);
 
-our $VERSION = '0.10';
+our $VERSION = '0.12';
 use English qw( -no_match_vars ); # Avoids reg-ex performance penalty
 local $OUTPUT_AUTOFLUSH = 1;
 
@@ -93,7 +93,6 @@ has 'padre' => (
 		croak "$_[0] this is not a Bool"
 			unless is_Bool( $_[0] );
 	},
-	lazy => 1,
 	default => sub {
 		0;
 	},
@@ -124,45 +123,67 @@ has 'twins' => (
 	required => 1,
 );
 
-#######
-# some encapsulated attributes
-#######
-
-has 'package_name' => (
-	is  => 'rw',
-	isa => Str,
-);
-
-has 'package_names' => (
-	is  => 'rw',
-	isa => ArrayRef,
-);
-
-has 'requires' => (
-	is  => 'rw',
-	isa => HashRef,
-);
-
-has 'test_requires' => (
-	is  => 'rw',
-	isa => HashRef,
-);
-
-has 'recommends' => (
-	is  => 'rw',
-	isa => HashRef,
-);
-
-has 'found_twins' => (
-	is      => 'rw',
-	isa     => Bool,
-	lazy => 1,
+has 'zero' => (
+	is  => 'ro',
+	isa => sub {
+		croak "$_[0] this is not a Bool"
+			unless is_Bool( $_[0] );
+	},
 	default => sub {
 		0;
 	},
 	required => 1,
 );
 
+#######
+# some encapsulated attributes
+#######
+
+has 'package_name' => (
+	is   => 'rw',
+	isa  => Str,
+	lazy => 1,
+);
+
+has 'package_names' => (
+	is   => 'rw',
+	isa  => ArrayRef,
+	lazy => 1,
+);
+
+has 'requires' => (
+	is   => 'rw',
+	isa  => HashRef,
+	lazy => 1,
+);
+
+has 'test_requires' => (
+	is   => 'rw',
+	isa  => HashRef,
+	lazy => 1,
+);
+
+has 'recommends' => (
+	is   => 'rw',
+	isa  => HashRef,
+	lazy => 1,
+);
+
+has 'found_twins' => (
+	is      => 'rw',
+	isa     => Bool,
+	lazy    => 1,
+	default => sub {
+		0;
+	},
+	required => 1,
+);
+
+has 'ppi_document' => (
+	is   => 'rw',
+	isa  => Object,
+	lazy => 1,
+);
 
 1;
 
@@ -178,9 +199,13 @@ App::Midgen::Roles - Package Options and Attributes used by L<App::Midgen>
 
 =head1 VERSION
 
-This document describes App::Midgen::Roles version: 0.10
+This document describes App::Midgen::Roles version: 0.12
 
-=head1 OPTIONS
+=head1 METHODS
+
+none as such, but we do have
+
+=head2 OPTIONS
 
 =over 4
 
@@ -202,11 +227,13 @@ This document describes App::Midgen::Roles version: 0.10
 
 =item * verbose
 
+=item * zero
+
 =back
 
 for more info see L<midgen>
 
-=head1 ACCESSORS
+=head2 ACCESSORS
 
 =over 4
 
@@ -222,6 +249,14 @@ Our best guess as to this packages name
 
 Some package names we found along the way
 
+=item * ppi_document
+
+I encapsulated this and got a nifty speed increase
+
+=item * recommends
+
+Some where to store recommend modules and version info in
+
 =item * requires
 
 Some where to store required modules and version info in
@@ -230,55 +265,27 @@ Some where to store required modules and version info in
 
 Some where to store test_required modules and version info in
 
-=item * recommends
-
-Some where to store recommend modules and version info in
 
 =back
 
-
-=head1 AUTHOR
-
-Kevin Dawson E<lt>bowtie@cpan.orgE<gt>
-
-=head2 CONTRIBUTORS
-
-none at present
-
-=head1 COPYRIGHT
-
-Copyright E<copy> 2013 AUTHOR and CONTRIBUTORS as listed above.
-
-=head1 LICENSE
-
-This program is free software; you can redistribute it and/or
-modify it under the same terms as Perl 5 itself.
-
 =head1 SEE ALSO
 
 L<App::Midgen>,
 
-=head1 DISCLAIMER OF WARRANTY
+=head1 AUTHOR
 
-BECAUSE THIS SOFTWARE IS LICENSED FREE OF CHARGE, THERE IS NO WARRANTY
-FOR THE SOFTWARE, TO THE EXTENT PERMITTED BY APPLICABLE LAW. EXCEPT WHEN
-OTHERWISE STATED IN WRITING THE COPYRIGHT HOLDERS AND/OR OTHER PARTIES
-PROVIDE THE SOFTWARE "AS IS" WITHOUT WARRANTY OF ANY KIND, EITHER
-EXPRESSED OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
-WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE. THE
-ENTIRE RISK AS TO THE QUALITY AND PERFORMANCE OF THE SOFTWARE IS WITH
-YOU. SHOULD THE SOFTWARE PROVE DEFECTIVE, YOU ASSUME THE COST OF ALL
-NECESSARY SERVICING, REPAIR, OR CORRECTION.
+See L<App::Midgen>
 
-IN NO EVENT UNLESS REQUIRED BY APPLICABLE LAW OR AGREED TO IN WRITING
-WILL ANY COPYRIGHT HOLDER, OR ANY OTHER PARTY WHO MAY MODIFY AND/OR
-REDISTRIBUTE THE SOFTWARE AS PERMITTED BY THE ABOVE LICENCE, BE
-LIABLE TO YOU FOR DAMAGES, INCLUDING ANY GENERAL, SPECIAL, INCIDENTAL,
-OR CONSEQUENTIAL DAMAGES ARISING OUT OF THE USE OR INABILITY TO USE
-THE SOFTWARE (INCLUDING BUT NOT LIMITED TO LOSS OF DATA OR DATA BEING
-RENDERED INACCURATE OR LOSSES SUSTAINED BY YOU OR THIRD PARTIES OR A
-FAILURE OF THE SOFTWARE TO OPERATE WITH ANY OTHER SOFTWARE), EVEN IF
-SUCH HOLDER OR OTHER PARTY HAS BEEN ADVISED OF THE POSSIBILITY OF
-SUCH DAMAGES.
+=head2 CONTRIBUTORS
+
+See L<App::Midgen>
+
+=head1 COPYRIGHT
+
+See L<App::Midgen>
+
+=head1 LICENSE
+
+See L<App::Midgen>
 
 =cut
